@@ -6,7 +6,8 @@ from agentex.lib.utils.logging import make_logger
 from agentex.lib.utils.debug import setup_debug_if_enabled
 from agentex.lib.environment_variables import EnvironmentVariables
 
-from workflow import At000HelloAcpWorkflow
+from project.workflow import At000HelloAcpWorkflow
+
 
 
 environment_variables = EnvironmentVariables.refresh()
