@@ -2,7 +2,7 @@ from typing import override
 from agentex.lib.sdk.state_machine import StateWorkflow, StateMachine
 from agentex.lib.utils.logging import make_logger
 from temporalio import workflow
-from state_machines.deep_research import DeepResearchData, DeepResearchState
+from project.state_machines.deep_research import DeepResearchData, DeepResearchState
 
 logger = make_logger(__name__)
 
