@@ -4,6 +4,7 @@ from typing import Any, Literal
 from agentex.lib.adk.utils._modules.client import create_async_agentex_client
 from agents import Agent, RunResult, RunResultStreaming
 from agents.agent import StopAtTools, ToolsToFinalOutputFunction
+from agents.guardrail import InputGuardrail, OutputGuardrail
 from agents.agent_output import AgentOutputSchemaBase
 from agents.model_settings import ModelSettings
 from agents.tool import Tool
@@ -80,10 +81,13 @@ class OpenAIModule:
         tools: list[Tool] | None = None,
         output_type: type[Any] | AgentOutputSchemaBase | None = None,
         tool_use_behavior: (
-            Literal["run_llm_again", "stop_on_first_tool"]
-            | StopAtTools
-            | ToolsToFinalOutputFunction
+            Literal["run_llm_again", "stop_on_first_tool"] | StopAtTools | ToolsToFinalOutputFunction
         ) = "run_llm_again",
+        mcp_timeout_seconds: int | None = None,
+        input_guardrails: list[InputGuardrail] | None = None,
+        output_guardrails: list[OutputGuardrail] | None = None,
+        max_turns: int | None = None,
+        previous_response_id: str | None = None,
     ) -> SerializableRunResult | RunResult:
         """
         Run an agent without streaming or TaskMessage creation.
@@ -107,6 +111,11 @@ class OpenAIModule:
             tools: Optional list of tools.
             output_type: Optional output type.
             tool_use_behavior: Optional tool use behavior.
+            mcp_timeout_seconds: Optional param to set the timeout threshold for the MCP servers. Defaults to 5 seconds.
+            input_guardrails: Optional list of input guardrails to run on initial user input.
+            output_guardrails: Optional list of output guardrails to run on final agent output.
+            max_turns: Maximum number of turns the agent can take. Uses Runner's default if None.
+            previous_response_id: Optional previous response ID for conversation continuity.
 
         Returns:
             Union[SerializableRunResult, RunResult]: SerializableRunResult when in Temporal, RunResult otherwise.
@@ -126,6 +135,11 @@ class OpenAIModule:
                 tools=tools,
                 output_type=output_type,
                 tool_use_behavior=tool_use_behavior,
+                mcp_timeout_seconds=mcp_timeout_seconds,
+                input_guardrails=input_guardrails,
+                output_guardrails=output_guardrails,
+                max_turns=max_turns,
+                previous_response_id=previous_response_id,
             )
             return await ActivityHelpers.execute_activity(
                 activity_name=OpenAIActivityName.RUN_AGENT,
@@ -150,6 +164,11 @@ class OpenAIModule:
                 tools=tools,
                 output_type=output_type,
                 tool_use_behavior=tool_use_behavior,
+                mcp_timeout_seconds=mcp_timeout_seconds,
+                input_guardrails=input_guardrails,
+                output_guardrails=output_guardrails,
+                max_turns=max_turns,
+                previous_response_id=previous_response_id,
             )
 
     async def run_agent_auto_send(
@@ -171,10 +190,13 @@ class OpenAIModule:
         tools: list[Tool] | None = None,
         output_type: type[Any] | AgentOutputSchemaBase | None = None,
         tool_use_behavior: (
-            Literal["run_llm_again", "stop_on_first_tool"]
-            | StopAtTools
-            | ToolsToFinalOutputFunction
+            Literal["run_llm_again", "stop_on_first_tool"] | StopAtTools | ToolsToFinalOutputFunction
         ) = "run_llm_again",
+        mcp_timeout_seconds: int | None = None,
+        input_guardrails: list[InputGuardrail] | None = None,
+        output_guardrails: list[OutputGuardrail] | None = None,
+        max_turns: int | None = None,
+        previous_response_id: str | None = None,
     ) -> SerializableRunResult | RunResult:
         """
         Run an agent with automatic TaskMessage creation.
@@ -197,6 +219,11 @@ class OpenAIModule:
             tools: Optional list of tools.
             output_type: Optional output type.
             tool_use_behavior: Optional tool use behavior.
+            mcp_timeout_seconds: Optional param to set the timeout threshold for the MCP servers. Defaults to 5 seconds.
+            input_guardrails: Optional list of input guardrails to run on initial user input.
+            output_guardrails: Optional list of output guardrails to run on final agent output.
+            max_turns: Maximum number of turns the agent can take. Uses Runner's default if None.
+            previous_response_id: Optional previous response ID for conversation continuity.
 
         Returns:
             Union[SerializableRunResult, RunResult]: SerializableRunResult when in Temporal, RunResult otherwise.
@@ -217,6 +244,11 @@ class OpenAIModule:
                 tools=tools,
                 output_type=output_type,
                 tool_use_behavior=tool_use_behavior,
+                mcp_timeout_seconds=mcp_timeout_seconds,
+                input_guardrails=input_guardrails,
+                output_guardrails=output_guardrails,
+                max_turns=max_turns,
+                previous_response_id=previous_response_id,
             )
             return await ActivityHelpers.execute_activity(
                 activity_name=OpenAIActivityName.RUN_AGENT_AUTO_SEND,
@@ -242,6 +274,11 @@ class OpenAIModule:
                 tools=tools,
                 output_type=output_type,
                 tool_use_behavior=tool_use_behavior,
+                mcp_timeout_seconds=mcp_timeout_seconds,
+                input_guardrails=input_guardrails,
+                output_guardrails=output_guardrails,
+                max_turns=max_turns,
+                previous_response_id=previous_response_id,
             )
 
     async def run_agent_streamed(
@@ -259,10 +296,13 @@ class OpenAIModule:
         tools: list[Tool] | None = None,
         output_type: type[Any] | AgentOutputSchemaBase | None = None,
         tool_use_behavior: (
-            Literal["run_llm_again", "stop_on_first_tool"]
-            | StopAtTools
-            | ToolsToFinalOutputFunction
+            Literal["run_llm_again", "stop_on_first_tool"] | StopAtTools | ToolsToFinalOutputFunction
         ) = "run_llm_again",
+        mcp_timeout_seconds: int | None = None,
+        input_guardrails: list[InputGuardrail] | None = None,
+        output_guardrails: list[OutputGuardrail] | None = None,
+        max_turns: int | None = None,
+        previous_response_id: str | None = None,
     ) -> RunResultStreaming:
         """
         Run an agent with streaming enabled but no TaskMessage creation.
@@ -289,6 +329,11 @@ class OpenAIModule:
             tools: Optional list of tools.
             output_type: Optional output type.
             tool_use_behavior: Optional tool use behavior.
+            mcp_timeout_seconds: Optional param to set the timeout threshold for the MCP servers. Defaults to 5 seconds.
+            input_guardrails: Optional list of input guardrails to run on initial user input.
+            output_guardrails: Optional list of output guardrails to run on final agent output.
+            max_turns: Maximum number of turns the agent can take. Uses Runner's default if None.
+            previous_response_id: Optional previous response ID for conversation continuity.
 
         Returns:
             RunResultStreaming: The result of the agent run with streaming.
@@ -318,6 +363,11 @@ class OpenAIModule:
             tools=tools,
             output_type=output_type,
             tool_use_behavior=tool_use_behavior,
+            mcp_timeout_seconds=mcp_timeout_seconds,
+            input_guardrails=input_guardrails,
+            output_guardrails=output_guardrails,
+            max_turns=max_turns,
+            previous_response_id=previous_response_id,
         )
 
     async def run_agent_streamed_auto_send(
@@ -339,11 +389,13 @@ class OpenAIModule:
         tools: list[Tool] | None = None,
         output_type: type[Any] | AgentOutputSchemaBase | None = None,
         tool_use_behavior: (
-            Literal["run_llm_again", "stop_on_first_tool"]
-            | StopAtTools
-            | ToolsToFinalOutputFunction
+            Literal["run_llm_again", "stop_on_first_tool"] | StopAtTools | ToolsToFinalOutputFunction
         ) = "run_llm_again",
         mcp_timeout_seconds: int | None = None,
+        input_guardrails: list[InputGuardrail] | None = None,
+        output_guardrails: list[OutputGuardrail] | None = None,
+        max_turns: int | None = None,
+        previous_response_id: str | None = None,
     ) -> SerializableRunResultStreaming | RunResultStreaming:
         """
         Run an agent with streaming enabled and automatic TaskMessage creation.
@@ -364,9 +416,13 @@ class OpenAIModule:
             model: Optional model to use.
             model_settings: Optional model settings.
             tools: Optional list of tools.
+            input_guardrails: Optional list of input guardrails to run on initial user input.
+            output_guardrails: Optional list of output guardrails to run on final agent output.
             output_type: Optional output type.
             tool_use_behavior: Optional tool use behavior.
             mcp_timeout_seconds: Optional param to set the timeout threshold for the MCP servers. Defaults to 5 seconds.
+            max_turns: Maximum number of turns the agent can take. Uses Runner's default if None.
+            previous_response_id: Optional previous response ID for conversation continuity.
 
         Returns:
             Union[SerializableRunResultStreaming, RunResultStreaming]: SerializableRunResultStreaming when in Temporal, RunResultStreaming otherwise.
@@ -388,6 +444,9 @@ class OpenAIModule:
                 output_type=output_type,
                 tool_use_behavior=tool_use_behavior,
                 mcp_timeout_seconds=mcp_timeout_seconds,
+                input_guardrails=input_guardrails,
+                output_guardrails=output_guardrails,
+                max_turns=max_turns,
             )
             return await ActivityHelpers.execute_activity(
                 activity_name=OpenAIActivityName.RUN_AGENT_STREAMED_AUTO_SEND,
@@ -414,4 +473,8 @@ class OpenAIModule:
                 output_type=output_type,
                 tool_use_behavior=tool_use_behavior,
                 mcp_timeout_seconds=mcp_timeout_seconds,
+                input_guardrails=input_guardrails,
+                output_guardrails=output_guardrails,
+                max_turns=max_turns,
+                previous_response_id=previous_response_id,
             )
